# Generated by Django 2.1.5 on 2019-01-16 20:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import staff.conf


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('politico_title', models.CharField(blank=True, max_length=100, null=True, verbose_name='Title')),
                ('politico_author_page', models.URLField(blank=True, null=True, verbose_name='Author page')),
                ('slack_api_id', models.CharField(blank=True, max_length=50, null=True, verbose_name='ID')),
                ('slack_image', models.ImageField(blank=True, null=True, upload_to=staff.conf.default_user_image_upload_to, verbose_name='Profile pic')),
                ('google_email', models.EmailField(blank=True, max_length=254, null=True, verbose_name='Gmail')),
                ('google_display_name', models.CharField(blank=True, max_length=250, null=True, verbose_name='Display name')),
                ('twitter_handle', models.CharField(blank=True, max_length=250, null=True, verbose_name='Handle')),
                ('user', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, to=settings.AUTH_USER_MODEL)),
            ],
        ),
    ]
